
#ifndef PDF_UPDATOR_H
#define PDF_UPDATOR_H

#include <string>
#include "../Page_no/PS_page_numbering.h"
#include "../TOC/Table.h"
#include "PDF.h"

// ---------------------------------------------------------------------
// To produce an update string suitable for appending to the PDF.
// ---------------------------------------------------------------------

// (Is "updator" a word?  This programmer does not know, but it fits
// nevertheless.)

namespace PDF {
  std::string updator(
    PDF &pdf,
    const Page_no::PS_page_numbering &nog,
    const TOC::Table &toc,
    const std::string &title = std::string()
  );
  std::string updator(
    const std::string &filename_pdf,
    const std::string &filename_ps,
    const std::string &filename_toc,
    const std::string &title = std::string()
  );
}

#endif

